@@ -18,6 +18,8 @@ from cloudmesh.shell.command import command
 from cloudmesh.shell.command import map_parameters
 # from cloudmesh.common.debug import VERBOSE
 from cloudmesh.burn.Imager import Imager
+from cloudmesh.common.util import yn_choice
+from cloudmesh.common.debug import VERBOSE
 
 
 class BurnCommand(PluginCommand):
@@ -50,6 +52,9 @@ class BurnCommand(PluginCommand):
                            [--ip=IP]
                            [--ssid=SSID]
                            [--wifipassword=PSK]
+                           [--bs=BLOCKSIZE]
+                           [-y]
+                           [-g]
               burn create [--image=IMAGE]
                           [--device=DEVICE]
                           [--hostname=HOSTNAME]
@@ -64,10 +69,12 @@ class BurnCommand(PluginCommand):
                           [--tag=TAG]
                           [--inventory=INVENTORY]
                           [--name=NAME]
+                          [-y]
               burn sdcard [TAG...] [--device=DEVICE] [--dryrun]
               burn set [--hostname=HOSTNAME]
                        [--ip=IP]
                        [--key=KEY]
+                       [--keyboard=COUNTRY]
               burn enable ssh
               burn wifi --ssid=SSID [--passwd=PASSWD] [--country=COUNTRY]
               burn check [--device=DEVICE]
@@ -145,41 +152,43 @@ class BurnCommand(PluginCommand):
 
                 cms burn firmware check
 
-                    checks if the firmware on the Pi is up to date
+                    Checks if the firmware on the Pi is up to date
 
                 cms burn firmware update
 
-                    checks and updates the firmware on the Pi
+                    Checks and updates the firmware on the Pi
 
                 cms burn install
 
-                    installs a program to shrink img files. THis is
+                    Installs a program to shrink img files. THis is
                     useful, after you created a backup to make the
                     backup smaller and allow faster burning in case of
                     recovery
 
+                    This command is not supported on MacOS
+
                 cms burn load --device=DEVICE
 
-                    loads the sdcard into the USB drive. Thi sis similar to
+                    Loads the sdcard into the USB drive. Thi sis similar to
                     loading a cdrom drive. It s the opposite to eject
 
                 cms burn format --device=DEVICE
 
-                    formats the SDCard in the specified device. Be
+                    Formats the SDCard in the specified device. Be
                     careful it is the correct device.  cms burn info
                     will help you to identifying it
 
                 cms burn mount [--device=DEVICE] [--os=OS]
 
-                    mounts the file systems available on the SDCard
+                    Mounts the file systems available on the SDCard
 
                 cms burn unmount [--device=DEVICE] [--os=OS]
 
-                    unmounts the mounted file systems from the SDCard
+                    Unmounts the mounted file systems from the SDCard
 
                 cms burn info [--device=DEVICE]
 
-                    provides useful information about the SDCard
+                    Provides useful information about the SDCard
 
                 cms burn image versions [--refresh] [--yaml]
 
@@ -197,32 +206,38 @@ class BurnCommand(PluginCommand):
 
                 cms burn image delete [--image=IMAGE]
 
-                    deletes the specified image. The name can be found
+                    Deletes the specified image. The name can be found
                     with the image ls command
 
                 cms burn image get [--url=URL] [TAG...]
 
-                    downloads a specific image or the latest
+                    Downloads a specific image or the latest
                     image. The tag are a number of words separated by
                     a space that must occur in the tag that you find
                     in the versions command
 
                 cms burn backup [--device=DEVICE] [--to=DESTINATION]
 
-                    backs up a SDCard to the given location
+                    This command requires you to install pishrink previously with
+
+                        cms burn install
+
+                    Backs up a SDCard to the given location.
 
                 cms burn copy [--device=DEVICE] [--from=DESTINATION]
 
-                    copies the file form the destination on the SDCard
+                    Copies the file form the destination on the SDCard
                     this is the same as the SDCard command. we will in
                     future remove one
 
                 cms burn shrink [--image=IMAGE]
 
-                    shrinks the size of a backup or image file that
+                    Shrinks the size of a backup or image file that
                     is on your local file system. It can only be used
                     for .img files
 
+                   This command is not supported on MacOS.
+
                 cms burn create [--image=IMAGE]
                                 [--device=DEVICE]
                                 [--hostname=HOSTNAME]
@@ -246,8 +261,9 @@ class BurnCommand(PluginCommand):
                              [--ip=IP]
                              [--key=KEY]
                              [--mount=MOUNTPOINT]
+                             [--keyboard=COUNTRY]
 
-                    this sets specific values on the sdcard after it
+                    Sets specific values on the sdcard after it
                     has ben created with the create, copy or sdcard
                     command
 
@@ -255,11 +271,11 @@ class BurnCommand(PluginCommand):
 
                 cms burn enable ssh [--mount=MOUNTPOINT]
 
-                    this enables the ssh server once it is booted
+                    Enables the ssh server once it is booted
 
                 cms burn wifi --ssid=SSID [--passwd=PASSWD] [--country=COUNTRY]
 
-                    this sets the wifi ssid and password after the card
+                    Sets the wifi ssid and password after the card
                     is created, copied, or the sdcard is used.
 
                     The option country option expects an ISO 3166-1
@@ -270,7 +286,7 @@ class BurnCommand(PluginCommand):
 
                 cms burn check [--device=DEVICE]
 
-                    this command lists the parameters that were set
+                    Lists the parameters that were set
                     with the set or create command
 
             Examples: ( \\ is not shown)
@@ -303,6 +319,7 @@ class BurnCommand(PluginCommand):
                        "ssid",
                        "url",
                        "key",
+                       "keyboard",
                        "passwd",
                        "wifipassword",
                        "version",
@@ -310,12 +327,18 @@ class BurnCommand(PluginCommand):
                        "os",
                        "country",
                        "inventory",
-                       "name")
+                       "name",
+                       "bs")
+
+        VERBOSE(arguments)
         # arguments.MOUNTPOINT = arguments["--mount"]
         arguments.FORMAT = arguments["--format"]
         arguments.FROM = arguments["--from"]
         arguments.IMAGE = arguments["--image"]
         arguments.output = "table"  # hard code for now
+        arguments.bs = arguments.bs or "4M"
+        arguments.gui = arguments["-g"]
+        arguments.yes = arguments["-y"]
 
         # VERBOSE(arguments)
 
@@ -397,6 +420,10 @@ class BurnCommand(PluginCommand):
 
         elif arguments.network and arguments["list"]:
 
+            if os_is_mac():
+                Console.error("Not yet implemented on MacOS")
+                return ""
+
             ip = arguments.ip or Network.address()[0]['local']
 
             details = Network.nmap(ip=ip)
@@ -416,6 +443,10 @@ class BurnCommand(PluginCommand):
 
         elif arguments.network:
 
+            if os_is_mac():
+                Console.error("Not yet implemented on MacOS")
+                return ""
+
             # print (Network.nmap())
             details = Network.address()
 
@@ -459,11 +490,19 @@ class BurnCommand(PluginCommand):
 
         elif arguments.install:
 
+            if os_is_mac():
+                Console.error("Not yet implemented on MacOS")
+                return ""
+
             execute("install", burner.install())
             return ""
 
         elif arguments.shrink:
 
+            if os_is_mac():
+                Console.error("Not yet implemented on MacOS")
+                return ""
+
             execute("shrink", burner.shrink(image=arguments.IMAGE))
             return ""
 
@@ -509,6 +548,9 @@ class BurnCommand(PluginCommand):
             if arguments.key:
                 execute("set key", burner.set_key(arguments.key))
 
+            if arguments.keyboard:
+                execute("set keyboard", burner.set_keyboard(country=arguments.keyboard))
+
             return ""
 
         elif arguments.enable and arguments.ssh:
@@ -563,8 +605,13 @@ class BurnCommand(PluginCommand):
 
         elif arguments.create and arguments.inventory:
             if not os_is_pi():
-                Console.error("This command has only been safely tested on Raspberry Pis. Terminating for caution")
-                return
+                print()
+                Console.error("This command has only been written for a  Raspberry Pis. Terminating for caution")
+                print()
+                if yn_choice("Continue anyways?"):
+                    pass
+                else:
+                    return
             if not arguments.name:
                 Console.error("Missing --name parameter. See cms help burn for usage")
                 return ""
@@ -572,14 +619,19 @@ class BurnCommand(PluginCommand):
                 Console.error("Missing --device parameter. See cms help burn for usage")
                 return ""
 
+            StopWatch.start("burn inventory")
             multi_burner = MultiBurner()
             # Perhaps we want to change the path at some point
             inventory = f"~/.cloudmesh/{arguments.inventory}"
-            execute("burn inventory",
-                    multi_burner.burn_inventory(
-                        inventory=inventory,
-                        name=arguments.name,
-                        device=arguments.device))
+            multi_burner.burn_inventory(
+                inventory=inventory,
+                name=arguments.name,
+                device=arguments.device,
+                yes=arguments.yes
+            )
+            StopWatch.stop("burn inventory")
+            StopWatch.status("burn inventory", True)
+            StopWatch.benchmark(sysinfo=False, csv=False)
             return ""
 
         elif arguments.create:
@@ -638,7 +690,9 @@ class BurnCommand(PluginCommand):
                     password=passwd,
                     ssid=ssid,
                     psk=psk,
-                    tag=tag)
+                    tag=tag,
+                    yes=arguments.yes
+                )
 
                 StopWatch.stop("total")
                 StopWatch.status("total", True)
